@@ -1,7 +1,7 @@
 package Data::Unixish::num;
 
-our $DATE = '2017-07-10'; # DATE
-our $VERSION = '1.56'; # VERSION
+our $DATE = '2019-01-06'; # DATE
+our $VERSION = '1.570'; # VERSION
 
 use 5.010;
 use locale;
@@ -174,7 +174,7 @@ Data::Unixish::num - Format number
 
 =head1 VERSION
 
-This document describes version 1.56 of Data::Unixish::num (from Perl distribution Data-Unixish), released on 2017-07-10.
+This document describes version 1.570 of Data::Unixish::num (from Perl distribution Data-Unixish), released on 2019-01-06.
 
 =head1 SYNOPSIS
 
@@ -197,7 +197,7 @@ In command line:
 
 Usage:
 
- num(%args) -> [status, msg, result, meta]
+ num(%args) -> [status, msg, payload, meta]
 
 Format number.
 
@@ -266,7 +266,7 @@ Returns an enveloped result (an array).
 First element (status) is an integer containing HTTP status code
 (200 means OK, 4xx caller error, 5xx function error). Second element
 (msg) is a string containing error message, or 'OK' if status is
-200. Third element (result) is optional, the actual result. Fourth
+200. Third element (payload) is optional, the actual result. Fourth
 element (meta) is called result metadata and is optional, a hash
 that contains extra information.
 
@@ -294,7 +294,7 @@ perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2017, 2016, 2015, 2014, 2013, 2012 by perlancar@cpan.org.
+This software is copyright (c) 2019, 2017, 2016, 2015, 2014, 2013, 2012 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
